@@ -7,7 +7,7 @@ use warnings;
 use parent qw(Plack::Middleware);
 use Plack::Util::Accessor qw(
                                 default_output_format
-                                allowable_output_formats
+                                allowed_output_formats
                                 time_limit
                         );
 
@@ -18,11 +18,11 @@ use Scalar::Util qw(blessed);
 use Sub::Spec::Util qw(str_log_level);
 use Time::HiRes qw(gettimeofday);
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 sub prepare_app {
     my $self = shift;
-    $self->{allowable_output_formats} //= [qw/html json phps yaml/];
+    $self->{allowed_output_formats} //= [qw/html json phps yaml/];
 }
 
 sub _pick_default_format {
@@ -110,7 +110,7 @@ sub call {
     return errpage("Unknown output format: $ofmt")
         unless $ofmt =~ /^\w+/ && $self->can("format_$ofmt");
     return errpage("Output format $ofmt not allowed")
-        unless allowed($ofmt, $self->allowable_output_formats);
+        unless allowed($ofmt, $self->allowed_output_formats);
 
     return sub {
         my $respond = shift;
@@ -147,6 +147,7 @@ sub call {
             Log::Any::Adapter->set(
                 {lexically=>\my $lex},
                 "Callback",
+                min_level => $loglvl,
                 logging_cb => sub {
                     my ($method, $self, $format, @params) = @_;
                     my $msg = join(
@@ -197,7 +198,7 @@ Plack::Middleware::SubSpec::HandleCommand - Handle command
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -226,7 +227,7 @@ key.
 If unspecified, some detection logic will be done to determine default format:
 if client is a GUI browser, 'html'; otherwise, 'json'.
 
-=item * allowable_output_formats => ARRAY|REGEX (default [qw/html json phps yaml/])
+=item * allowed_output_formats => ARRAY|REGEX (default [qw/html json phps yaml/])
 
 Specify what output formats are allowed. When client requests an unallowed
 format, 400 error is returned.
